Welcome to the MobsPy's documentation!
======================================

.. toctree::
   :maxdepth: 2

   readme
   tutorial
   application

API
===

This section summarizes the API of MobsPy.

.. autosummary::
   :toctree: _autosummary
   :recursive:

   mobspy